@@ -6,7 +6,6 @@ pub use self::{
     pure_annotations::pure_annotations,
     refresh::{options::RefreshOptions, refresh},
 };
-use std::mem;
 use swc_common::{chain, comments::Comments, sync::Lrc, Mark, SourceMap};
 use swc_ecma_visit::Fold;
 
@@ -41,7 +40,7 @@ where
 {
     let Options { development, .. } = options;
 
-    let refresh_options = mem::replace(&mut options.refresh, None);
+    let refresh_options = options.refresh.take();
 
     chain!(
         jsx_src(development, cm.clone()),
